==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess.md <==
# AmazonElasticFileSystemOneZoneInfrequentAccess


```text
aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess
```

```text
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')
```



| Illustration | AmazonElasticFileSystemOneZoneInfrequentAccess | AmazonElasticFileSystemOneZoneInfrequentAccessCard | AmazonElasticFileSystemOneZoneInfrequentAccessGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess.png) | ![illustration for AmazonElasticFileSystemOneZoneInfrequentAccess](../../../aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess.Local.png) | ![illustration for AmazonElasticFileSystemOneZoneInfrequentAccessCard](../../../aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccessCard.Local.png) | ![illustration for AmazonElasticFileSystemOneZoneInfrequentAccessGroup](../../../aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccessGroup.Local.png) |




## AmazonElasticFileSystemOneZoneInfrequentAccess

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccess
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccess('AmazonElasticFileSystemOneZoneInfrequentAccess', 'Amazon Elastic File System One Zone Infrequent Access', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccess
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccess('AmazonElasticFileSystemOneZoneInfrequentAccess', 'Amazon Elastic File System One Zone Infrequent Access', 'an optional tech label')
@enduml
```

## AmazonElasticFileSystemOneZoneInfrequentAccessCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccessCard
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccessCard('AmazonElasticFileSystemOneZoneInfrequentAccessCard', 'Amazon Elastic File System One Zone Infrequent Access Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccessCard
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccessCard('AmazonElasticFileSystemOneZoneInfrequentAccessCard', 'Amazon Elastic File System One Zone Infrequent Access Card', 'an optional description')
@enduml
```

## AmazonElasticFileSystemOneZoneInfrequentAccessGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccessGroup
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccessGroup('AmazonElasticFileSystemOneZoneInfrequentAccessGroup', 'Amazon Elastic File System One Zone Infrequent Access Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccessGroup
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccessGroup('AmazonElasticFileSystemOneZoneInfrequentAccessGroup', 'Amazon Elastic File System One Zone Infrequent Access Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess.md <==
# AmazonElasticFileSystemOneZoneInfrequentAccess


```text
aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess
```

```text
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')
```



| Illustration | AmazonElasticFileSystemOneZoneInfrequentAccess | AmazonElasticFileSystemOneZoneInfrequentAccessCard | AmazonElasticFileSystemOneZoneInfrequentAccessGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess.png) | ![illustration for AmazonElasticFileSystemOneZoneInfrequentAccess](../../../aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess.Local.png) | ![illustration for AmazonElasticFileSystemOneZoneInfrequentAccessCard](../../../aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccessCard.Local.png) | ![illustration for AmazonElasticFileSystemOneZoneInfrequentAccessGroup](../../../aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccessGroup.Local.png) |




## AmazonElasticFileSystemOneZoneInfrequentAccess

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccess
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccess('AmazonElasticFileSystemOneZoneInfrequentAccess', 'Amazon Elastic File System One Zone Infrequent Access', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccess
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccess('AmazonElasticFileSystemOneZoneInfrequentAccess', 'Amazon Elastic File System One Zone Infrequent Access', 'an optional tech label')
@enduml
```

## AmazonElasticFileSystemOneZoneInfrequentAccessCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccessCard
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccessCard('AmazonElasticFileSystemOneZoneInfrequentAccessCard', 'Amazon Elastic File System One Zone Infrequent Access Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccessCard
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccessCard('AmazonElasticFileSystemOneZoneInfrequentAccessCard', 'Amazon Elastic File System One Zone Infrequent Access Card', 'an optional description')
@enduml
```

## AmazonElasticFileSystemOneZoneInfrequentAccessGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccessGroup
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccessGroup('AmazonElasticFileSystemOneZoneInfrequentAccessGroup', 'Amazon Elastic File System One Zone Infrequent Access Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElasticFileSystemOneZoneInfrequentAccessGroup
include('aws-20210730/Resource/Storage/AmazonElasticFileSystemOneZoneInfrequentAccess')

' renders the element
AmazonElasticFileSystemOneZoneInfrequentAccessGroup('AmazonElasticFileSystemOneZoneInfrequentAccessGroup', 'Amazon Elastic File System One Zone Infrequent Access Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
